@@ -1,38 +1,46 @@
-from __future__ import unicode_literals
-
 from django.conf import settings
+from django.utils.translation import gettext_lazy as _
 
 from appconf import AppConf
 
 
-class MyAppConf(AppConf):
+class AxesAppConf(AppConf):
+    # disable plugin when set to False
+    ENABLED = True
+
     # see if the user has overridden the failure limit
     FAILURE_LIMIT = 3
 
     # see if the user has set axes to lock out logins after failure limit
     LOCK_OUT_AT_FAILURE = True
 
+    # lock out with the combination of username and IP address
+    LOCK_OUT_BY_COMBINATION_USER_AND_IP = False
+
+    # lock out with username and never the IP or user agent
+    ONLY_USER_FAILURES = False
+
+    # lock out with the user agent, has no effect when ONLY_USER_FAILURES is set
     USE_USER_AGENT = False
 
     # use a specific username field to retrieve from login POST data
     USERNAME_FORM_FIELD = 'username'
 
     # use a specific password field to retrieve from login POST data
-    PASSWORD_FORM_FIELD = 'password'
+    PASSWORD_FORM_FIELD = 'password'  # noqa
 
     # use a provided callable to transform the POSTed username into the one used in credentials
     USERNAME_CALLABLE = None
 
-    # only check user name and not location or user_agent
-    ONLY_USER_FAILURES = False
-
-    # lock out user from particular IP based on combination USER+IP
-    LOCK_OUT_BY_COMBINATION_USER_AND_IP = False
+    # reset the number of failed attempts after one successful attempt
+    RESET_ON_SUCCESS = False
 
     DISABLE_ACCESS_LOG = False
 
     DISABLE_SUCCESS_ACCESS_LOG = False
 
+    HANDLER = 'axes.handlers.database.AxesDatabaseHandler'
+
     LOGGER = 'axes.watch_login'
 
     LOCKOUT_TEMPLATE = None
@@ -44,9 +52,10 @@ class MyAppConf(AppConf):
     VERBOSE = True
 
     # whitelist and blacklist
-    # TODO: convert the strings to IPv4 on startup to avoid type conversion during processing
     NEVER_LOCKOUT_WHITELIST = False
 
+    NEVER_LOCKOUT_GET = False
+
     ONLY_WHITELIST = False
 
     IP_WHITELIST = None
@@ -54,10 +63,10 @@ class MyAppConf(AppConf):
     IP_BLACKLIST = None
 
     # message to show when locked out and have cooloff enabled
-    COOLOFF_MESSAGE = 'Account locked: too many login attempts. Please try again later'
+    COOLOFF_MESSAGE = _('Account locked: too many login attempts. Please try again later')
 
     # message to show when locked out and have cooloff disabled
-    PERMALOCK_MESSAGE = 'Account locked: too many login attempts. Contact an admin to unlock your account.'
+    PERMALOCK_MESSAGE = _('Account locked: too many login attempts. Contact an admin to unlock your account.')
 
     # if your deployment is using reverse proxies, set this value to 'left-most' or 'right-most' per your configuration
     PROXY_ORDER = 'left-most'
